@@ -89,9 +89,11 @@ class Lotus:
     def process_signals(self, ns, start=False):
         for symbol in self.symbols:
             if start:
-                self.order.check_open_bot_order(symbol, ns[symbol]['entry'], ns[symbol]['stoploss'])
-                time.sleep(3)
+                if ns[symbol]['signal']:
+                    self.order.check_open_bot_order(symbol, ns[symbol]['entry'], ns[symbol]['stoploss'])
+                    time.sleep(3)
             signal = ns[symbol]['signal']
+            print('Signal: {}'.format(signal), flush=True)
             if signal:
                 if self.is_new_signal_symbol(ns, symbol):
                     entry = ns[symbol]['entry']
@@ -169,7 +171,7 @@ class Lotus:
                             self.order.close(symbol)
             else:
                 self.manage_open_stop_orders(symbol)
-                print("This signal in {} is only for members.".format(symbol), flush=True)
+                print("This signal in {} is only for paid members.".format(symbol), flush=True)
 
     def run(self):
         # Main loop
